
/*
 *  header - $Id: memguard.h,v 1.3 1997/06/10 18:49:26 qian Exp $
 *
 *  API of the memory-based guard tool to the rest of the toolkit
 */


/*********************************************************************
types & constants
*********************************************************************/

#define COPY_STRUCT(tgt,src,fld)					{\
		memcpy((char *)(tgt), (char *)(src),			\
			(int)&(tgt)->fld - (int)(tgt));			\
		memcpy((char *)&(tgt)->fld + sizeof((tgt)->fld),	\
			(char *)&(src)->fld + sizeof((src)->fld),	\
			sizeof(*(src)) - ((int)&(tgt)->fld - (int)(tgt)	\
				+ sizeof((tgt)->fld)));			}


/*********************************************************************
variables
*********************************************************************/


/*********************************************************************
functions
*********************************************************************/

/*
 * Functions  : void mgReset(void)
 *              int mgEnable(void)
 *              int mgDisable(void)
 *              int mgAdd(char *name, caddr_t vaddr, u_int size)
 *              int mgDelete(caddr_t vaddr)
 *              int mgSet(caddr_t vaddr, u_int size, char *content)
 *              int mgGet(caddr_t vaddr, u_int size, char *content)
 *              int mgAssert(caddr_t vaddr, u_int size, char *content)
 *              int mgPrintErr(void)
 * Description: The MemGuard API
 */
/* reset the tool */
extern void mgReset(void);

/* enable the Tool's memguard page protection fault */
extern int mgEnable(void);
#    define MG_ENABLE_OK	0	/* success */
#    define MG_ENABLE_ENABLED	-1	/* already enabled */

/* disable the Tool's memguard page protection fault */
extern int mgDisable(void);
#    define MG_DISABLE_OK	0	/* success */
#    define MG_DISABLE_DISABLED	-1	/* already disabled */
  
/* add an invariant */
extern int mgAdd(char *name, caddr_t vaddr, u_int size);
#    define MG_ADD_OK		0	/* success */
#    define MG_ADD_VADDR	-1	/* invalid virtual address */
#    define MG_ADD_SIZE		-2	/* invalid size */
#    define MG_ADD_NAME		-3	/* invalid name */
#    define MG_ADD_CONFLICT	-4	/* conflict */
#    define MG_ADD_FULL		-5	/* too many invariants */

/* delete an invariant */
extern int mgDelete(caddr_t vaddr);
#    define MG_DELETE_OK	0	/* success */
#    define MG_DELETE_VADDR	-1	/* error virtual address:
					   non-exists */

/* set an invariant */
extern int mgSet(caddr_t vaddr, u_int size, char *content);
#    define MG_SET_OK		0	/* success */
#    define MG_SET_VADDR	-1	/* error virtual address:
					   non-exists */
#    define MG_SET_SIZE		-2	/* error size */
#    define MG_SET_CONTENT	-3	/* error content: copy */

/* get an invariant */
extern int mgGet(caddr_t vaddr, u_int size, char *content);
#    define MG_GET_OK		0	/* success */
#    define MG_GET_VADDR	-1	/* error virtual address:
					   non-exists */
#    define MG_GET_SIZE		-2	/* error size */
#    define MG_GET_CONTENT	-3	/* error content: copy */

/* assert an invariant */
extern int mgAssert(caddr_t vaddr, u_int size, char *content);
#    define MG_ASSERT_OK	0	/* success */
#    define MG_ASSERT_VADDR	-1	/* error virtual address:
					   non-exists */
#    define MG_ASSERT_SIZE	-2	/* error size */
#    define MG_ASSERT_CONTENT	-3	/* error content */

/* print an error message */
extern int mgPrintError(void);
#    define MG_PERROR_OK	0	/* success */
#    define MG_PERROR_ERROR	-1	/* error */

